@@ -9,7 +9,7 @@
 #
 package MooseX::Attribute::Deflator;
 BEGIN {
-  $MooseX::Attribute::Deflator::VERSION = '1.130002';
+  $MooseX::Attribute::Deflator::VERSION = '2.0.0';
 }
 # ABSTRACT: Deflates and inflates Moose attributes to and from a string
 
@@ -20,10 +20,11 @@ use MooseX::Attribute::Deflator::Registry;
 use Moose::Util qw();
 
 sub via (&) { $_[0] }
+sub inline (&) { $_[0] }
 
 Moose::Exporter->setup_import_methods(
     as_is => [
-        qw( deflate inflate via )
+        qw( deflate inflate via inline )
     ],
 );
 
@@ -32,13 +33,11 @@ my $REGISTRY = MooseX::Attribute::Deflator::Registry->new;
 sub get_registry { $REGISTRY }
 
 sub deflate {
-	my ($type_name, $via) = @_;
-	$REGISTRY->add_deflator($type_name, $via);
+	$REGISTRY->add_deflator(@_);
 }
 
 sub inflate {
-	my ($type_name, $via) = @_;
-	$REGISTRY->add_inflator($type_name, $via);
+	$REGISTRY->add_inflator(@_);
 }
 
 
@@ -56,7 +55,7 @@ MooseX::Attribute::Deflator - Deflates and inflates Moose attributes to and from
 
 =head1 VERSION
 
-version 1.130002
+version 2.0.0
 
 =head1 SYNOPSIS
 
